JBossWS SVN: r14195 - hudson/branches.
by jbossws-commits@lists.jboss.org
Author: alessio.soldano(a)jboss.com
Date: 2011-04-26 08:14:11 -0400 (Tue, 26 Apr 2011)
New Revision: 14195
Removed:
hudson/branches/jbossws-cxf-4.0.0.Alpha4/
Log:
Removing useless branch
13 years, 10 months
JBossWS SVN: r14194 - in stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf: transport and 1 other directory.
by jbossws-commits@lists.jboss.org
Author: alessio.soldano(a)jboss.com
Date: 2011-04-26 08:12:42 -0400 (Tue, 26 Apr 2011)
New Revision: 14194
Modified:
stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/RequestHandlerImpl.java
stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/transport/SoapTransportFactoryExt.java
Log:
Fixing address rewrite regressions and updating the soap transport factory integration point
Modified: stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/RequestHandlerImpl.java
===================================================================
--- stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/RequestHandlerImpl.java 2011-04-25 18:40:06 UTC (rev 14193)
+++ stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/RequestHandlerImpl.java 2011-04-26 12:12:42 UTC (rev 14194)
@@ -1,6 +1,6 @@
/*
* JBoss, Home of Professional Open Source.
- * Copyright 2006, Red Hat Middleware LLC, and individual contributors
+ * Copyright 2011, Red Hat Middleware LLC, and individual contributors
* as indicated by the @author tags. See the copyright.txt file in the
* distribution for a full listing of individual contributors.
*
@@ -36,17 +36,13 @@
import org.apache.cxf.Bus;
import org.apache.cxf.BusException;
-//import org.apache.cxf.BusFactory;
+import org.apache.cxf.frontend.WSDLGetInterceptor;
import org.apache.cxf.service.model.EndpointInfo;
-//import org.apache.cxf.transport.Destination;
import org.apache.cxf.transport.DestinationFactory;
import org.apache.cxf.transport.DestinationFactoryManager;
import org.apache.cxf.transport.http.AbstractHTTPDestination;
import org.apache.cxf.transport.http.DestinationRegistry;
import org.apache.cxf.transport.http.HTTPTransportFactory;
-//import org.apache.cxf.transport.http.HttpDestinationFactory;
-//import org.apache.cxf.transport.servlet.ServletController;
-//import org.apache.cxf.transport.servlet.ServletDestination;
import org.apache.cxf.transports.http.QueryHandler;
import org.apache.cxf.transports.http.QueryHandlerRegistry;
import org.jboss.util.NotImplementedException;
@@ -78,12 +74,6 @@
public void handleHttpRequest(Endpoint ep, HttpServletRequest req, HttpServletResponse res, ServletContext context) throws ServletException, IOException
{
-// ServletControllerExt controller = (ServletControllerExt)context.getAttribute(ServletController.class.getName());
-// if (controller == null)
-// throw new IllegalStateException("Cannot obtain servlet controller");
-//
-// controller.invoke(req, res, ep);
-
Bus bus = ep.getService().getDeployment().getAttachment(BusHolder.class).getBus();
AbstractHTTPDestination dest = findDestination(req, bus);
@@ -207,10 +197,8 @@
String ctxUri = req.getRequestURI();
String baseUri = req.getRequestURL().toString() + "?" + req.getQueryString();
EndpointInfo endpointInfo = dest.getEndpointInfo();
- if (ServerConfig.UNDEFINED_HOSTNAME.equals(serverConfig.getWebServiceHost()))
- {
- endpointInfo.setProperty("autoRewriteSoapAddress", true);
- }
+ endpointInfo.setProperty(WSDLGetInterceptor.AUTO_REWRITE_ADDRESS,
+ ServerConfig.UNDEFINED_HOSTNAME.equals(serverConfig.getWebServiceHost()));
for (QueryHandler queryHandler : bus.getExtension(QueryHandlerRegistry.class).getHandlers())
{
Modified: stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/transport/SoapTransportFactoryExt.java
===================================================================
--- stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/transport/SoapTransportFactoryExt.java 2011-04-25 18:40:06 UTC (rev 14193)
+++ stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/transport/SoapTransportFactoryExt.java 2011-04-26 12:12:42 UTC (rev 14194)
@@ -1,6 +1,6 @@
/*
* JBoss, Home of Professional Open Source.
- * Copyright 2009, Red Hat Middleware LLC, and individual contributors
+ * Copyright 2011, Red Hat Middleware LLC, and individual contributors
* as indicated by the @author tags. See the copyright.txt file in the
* distribution for a full listing of individual contributors.
*
@@ -24,9 +24,8 @@
import java.util.Iterator;
import java.util.List;
-import javax.wsdl.Port;
-
import org.apache.cxf.binding.soap.SoapTransportFactory;
+import org.apache.cxf.binding.soap.jms.interceptor.SoapJMSConstants;
import org.apache.cxf.binding.soap.model.SoapBindingInfo;
import org.apache.cxf.service.model.BindingInfo;
import org.apache.cxf.service.model.EndpointInfo;
@@ -50,22 +49,22 @@
public class SoapTransportFactoryExt extends SoapTransportFactory
{
private ServerConfig serverConfig;
-
- @SuppressWarnings("unchecked")
- public EndpointInfo createEndpointInfo(ServiceInfo serviceInfo, BindingInfo b, Port port)
+
+ @Override
+ public EndpointInfo createEndpointInfo(ServiceInfo serviceInfo, BindingInfo b, List<?> ees)
{
String transportURI = "http://schemas.xmlsoap.org/wsdl/soap/";
if (b instanceof SoapBindingInfo)
{
- SoapBindingInfo sbi = (SoapBindingInfo)b;
+ SoapBindingInfo sbi = (SoapBindingInfo) b;
transportURI = sbi.getTransportURI();
}
ServerConfig config = getServerConfig();
EndpointInfo info = new AddressRewritingEndpointInfo(serviceInfo, transportURI, config);
- if (port != null)
+
+ if (ees != null)
{
- List ees = port.getExtensibilityElements();
- for (Iterator itr = ees.iterator(); itr.hasNext();)
+ for (@SuppressWarnings("rawtypes")Iterator itr = ees.iterator(); itr.hasNext();)
{
Object extensor = itr.next();
@@ -75,6 +74,10 @@
info.addExtensor(sa);
info.setAddress(sa.getLocationURI());
+ if (isJMSSpecAddress(sa.getLocationURI()))
+ {
+ info.setTransportId(SoapJMSConstants.SOAP_JMS_SPECIFICIATION_TRANSPORTID);
+ }
}
else
{
@@ -82,9 +85,15 @@
}
}
}
+
return info;
}
-
+
+ private boolean isJMSSpecAddress(String address)
+ {
+ return address != null && address.startsWith("jms:") && !"jms://".equals(address);
+ }
+
private ServerConfig getServerConfig()
{
if (serverConfig == null)
13 years, 10 months
JBossWS SVN: r14193 - stack/native/branches/jbossws-native-3.1.2.SP3-patch-02_JBPAPP-6365/modules/core/src/main/java/org/jboss/ws/extensions/validation.
by jbossws-commits@lists.jboss.org
Author: klape
Date: 2011-04-25 14:40:06 -0400 (Mon, 25 Apr 2011)
New Revision: 14193
Modified:
stack/native/branches/jbossws-native-3.1.2.SP3-patch-02_JBPAPP-6365/modules/core/src/main/java/org/jboss/ws/extensions/validation/SchemaExtractor.java
Log:
[JBPAPP-6365] Also adding namespace declarations of the <types> parent tag
Modified: stack/native/branches/jbossws-native-3.1.2.SP3-patch-02_JBPAPP-6365/modules/core/src/main/java/org/jboss/ws/extensions/validation/SchemaExtractor.java
===================================================================
--- stack/native/branches/jbossws-native-3.1.2.SP3-patch-02_JBPAPP-6365/modules/core/src/main/java/org/jboss/ws/extensions/validation/SchemaExtractor.java 2011-04-25 16:05:02 UTC (rev 14192)
+++ stack/native/branches/jbossws-native-3.1.2.SP3-patch-02_JBPAPP-6365/modules/core/src/main/java/org/jboss/ws/extensions/validation/SchemaExtractor.java 2011-04-25 18:40:06 UTC (rev 14193)
@@ -71,7 +71,9 @@
// parse the wsdl
Element root = DOMUtils.parse(wsdlURL.openStream());
- List<Attr> nsAttrs = getNamespaceAttrs(root);
+ List<Attr> nsAttrs = new ArrayList<Attr>();
+
+ getNamespaceAttrs(root, nsAttrs);
// get the types element
QName typesQName = new QName(root.getNamespaceURI(), "types");
@@ -82,6 +84,8 @@
return null;
}
+ getNamespaceAttrs(typesEl, nsAttrs);
+
// get the schema element
QName schemaQName = new QName("http://www.w3.org/2001/XMLSchema", "schema");
List<Element> schemaElements = DOMUtils.getChildElementsAsList(typesEl, schemaQName);
@@ -122,10 +126,8 @@
return streams.toArray(new InputStream[streams.size()]);
}
- private List<Attr> getNamespaceAttrs(Element element)
+ private void getNamespaceAttrs(Element element, List<Attr> nsAttrs)
{
- List<Attr> nsAttrs = new ArrayList<Attr>();
-
NamedNodeMap nodes = element.getAttributes();
for(int i=0; i < nodes.getLength(); i++)
@@ -135,8 +137,6 @@
if(attr.getName().startsWith("xmlns"))
nsAttrs.add((Attr)attr.cloneNode(true));
}
-
- return nsAttrs;
}
private void pullImportedSchemas(Element schemaElement, List<InputStream> streams)
13 years, 10 months
JBossWS SVN: r14192 - stack/native/branches/jbossws-native-3.1.2.SP3-patch-02_JBPAPP-6365/modules/core/src/main/java/org/jboss/ws/extensions/validation.
by jbossws-commits@lists.jboss.org
Author: klape
Date: 2011-04-25 12:05:02 -0400 (Mon, 25 Apr 2011)
New Revision: 14192
Modified:
stack/native/branches/jbossws-native-3.1.2.SP3-patch-02_JBPAPP-6365/modules/core/src/main/java/org/jboss/ws/extensions/validation/SchemaExtractor.java
Log:
[JBWS-2235] Now copying namespace declarations from <definitions> tag to <schema> tag
Modified: stack/native/branches/jbossws-native-3.1.2.SP3-patch-02_JBPAPP-6365/modules/core/src/main/java/org/jboss/ws/extensions/validation/SchemaExtractor.java
===================================================================
--- stack/native/branches/jbossws-native-3.1.2.SP3-patch-02_JBPAPP-6365/modules/core/src/main/java/org/jboss/ws/extensions/validation/SchemaExtractor.java 2011-04-25 00:10:23 UTC (rev 14191)
+++ stack/native/branches/jbossws-native-3.1.2.SP3-patch-02_JBPAPP-6365/modules/core/src/main/java/org/jboss/ws/extensions/validation/SchemaExtractor.java 2011-04-25 16:05:02 UTC (rev 14192)
@@ -30,6 +30,7 @@
import java.io.InputStream;
import java.io.FileInputStream;
import java.net.URL;
+import java.util.Map;
import java.util.List;
import java.util.ArrayList;
import java.util.regex.Pattern;
@@ -42,6 +43,9 @@
import org.jboss.wsf.common.DOMWriter;
import org.jboss.wsf.common.IOUtils;
import org.w3c.dom.Element;
+import org.w3c.dom.Attr;
+import org.w3c.dom.Node;
+import org.w3c.dom.NamedNodeMap;
/**
* Extracts the schema from a given WSDL
@@ -67,6 +71,8 @@
// parse the wsdl
Element root = DOMUtils.parse(wsdlURL.openStream());
+ List<Attr> nsAttrs = getNamespaceAttrs(root);
+
// get the types element
QName typesQName = new QName(root.getNamespaceURI(), "types");
Element typesEl = DOMUtils.getFirstChildElement(root, typesQName);
@@ -90,6 +96,16 @@
}
Element schemaElement = schemaElements.get(0);
+ //Add namespace declarations from root element
+ for(Attr nsAttr : nsAttrs)
+ {
+ Attr replacedAttr = schemaElement.setAttributeNodeNS(nsAttr);
+ if(replacedAttr != null) //then put it back
+ {
+ schemaElement.setAttributeNodeNS(replacedAttr);
+ }
+ }
+
List<InputStream> streams = new ArrayList<InputStream>();
pullImportedSchemas(schemaElement, streams);
@@ -106,6 +122,23 @@
return streams.toArray(new InputStream[streams.size()]);
}
+ private List<Attr> getNamespaceAttrs(Element element)
+ {
+ List<Attr> nsAttrs = new ArrayList<Attr>();
+
+ NamedNodeMap nodes = element.getAttributes();
+
+ for(int i=0; i < nodes.getLength(); i++)
+ {
+ Node node = nodes.item(i);
+ Attr attr = (Attr)node;
+ if(attr.getName().startsWith("xmlns"))
+ nsAttrs.add((Attr)attr.cloneNode(true));
+ }
+
+ return nsAttrs;
+ }
+
private void pullImportedSchemas(Element schemaElement, List<InputStream> streams)
{
QName importQName = new QName( "http://www.w3.org/2001/XMLSchema", "import" );
13 years, 10 months
JBossWS SVN: r14191 - in stack/cxf/branches/cxf24/modules: server/src/main/java/org/jboss/wsf/stack/cxf/configuration and 1 other directories.
by jbossws-commits@lists.jboss.org
Author: alessio.soldano(a)jboss.com
Date: 2011-04-24 20:10:23 -0400 (Sun, 24 Apr 2011)
New Revision: 14191
Removed:
stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/configuration/JBossWSServerSpringConfigurer.java
Modified:
stack/cxf/branches/cxf24/modules/client/src/main/java/org/jboss/wsf/stack/cxf/client/configuration/JBossWSSpringConfigurer.java
stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/configuration/SpringBusHolder.java
stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/spring/parser/JaxwsEndpointDefinitionParser.java
Log:
fixing configurer integration w/ spring
Modified: stack/cxf/branches/cxf24/modules/client/src/main/java/org/jboss/wsf/stack/cxf/client/configuration/JBossWSSpringConfigurer.java
===================================================================
--- stack/cxf/branches/cxf24/modules/client/src/main/java/org/jboss/wsf/stack/cxf/client/configuration/JBossWSSpringConfigurer.java 2011-04-24 22:04:33 UTC (rev 14190)
+++ stack/cxf/branches/cxf24/modules/client/src/main/java/org/jboss/wsf/stack/cxf/client/configuration/JBossWSSpringConfigurer.java 2011-04-25 00:10:23 UTC (rev 14191)
@@ -22,6 +22,11 @@
package org.jboss.wsf.stack.cxf.client.configuration;
import org.apache.cxf.configuration.Configurer;
+import org.apache.cxf.configuration.spring.ConfigurerImpl;
+import org.apache.cxf.extension.BusExtension;
+import org.springframework.beans.BeansException;
+import org.springframework.context.ApplicationContext;
+import org.springframework.context.ApplicationContextAware;
/**
* A CXF delegate configurer that sets JBossWS stuff / customizations / properties etc. in CXF configurable beans
@@ -30,7 +35,7 @@
* @author alessio.soldano(a)jboss.com
* @since 05-Oct-2009
*/
-public class JBossWSSpringConfigurer implements JBossWSConfigurer
+public class JBossWSSpringConfigurer implements JBossWSConfigurer, ApplicationContextAware, BusExtension
{
private BeanCustomizer customizer;
private Configurer delegate;
@@ -54,6 +59,14 @@
delegate.configureBean(name, beanInstance);
}
+ public void addApplicationContext(ApplicationContext ctx)
+ {
+ if (delegate instanceof ConfigurerImpl)
+ {
+ ((ConfigurerImpl)delegate).addApplicationContext(ctx);
+ }
+ }
+
protected synchronized void customConfigure(Object beanInstance)
{
if (customizer != null)
@@ -71,4 +84,23 @@
{
this.customizer = customizer;
}
+
+ @Override
+ public Class<?> getRegistrationType()
+ {
+ if (delegate instanceof BusExtension)
+ {
+ return ((BusExtension)delegate).getRegistrationType();
+ }
+ throw new RuntimeException("Delegate is not a BusExtension instance: " + delegate);
+ }
+
+ @Override
+ public void setApplicationContext(ApplicationContext applicationContext) throws BeansException
+ {
+ if (delegate instanceof ApplicationContextAware)
+ {
+ ((ApplicationContextAware)delegate).setApplicationContext(applicationContext);
+ }
+ }
}
Deleted: stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/configuration/JBossWSServerSpringConfigurer.java
===================================================================
--- stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/configuration/JBossWSServerSpringConfigurer.java 2011-04-24 22:04:33 UTC (rev 14190)
+++ stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/configuration/JBossWSServerSpringConfigurer.java 2011-04-25 00:10:23 UTC (rev 14191)
@@ -1,46 +0,0 @@
-/*
- * JBoss, Home of Professional Open Source.
- * Copyright 2010, Red Hat Middleware LLC, and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
- */
-package org.jboss.wsf.stack.cxf.configuration;
-
-import org.apache.cxf.configuration.Configurer;
-import org.apache.cxf.configuration.spring.ConfigurerImpl;
-import org.jboss.wsf.stack.cxf.client.configuration.JBossWSSpringConfigurer;
-import org.springframework.context.ApplicationContext;
-
-/**
- * A JBossWS CXF Configurer (Spring based) to be used on server side
- *
- * @author alessio.soldano(a)jboss.com
- * @author ema(a)redhat.com
- * @since 31-Mar-2010
- */
-public class JBossWSServerSpringConfigurer extends JBossWSSpringConfigurer
-{
- public JBossWSServerSpringConfigurer(Configurer delegate, ApplicationContext ctx)
- {
- super(delegate);
- if (delegate instanceof ConfigurerImpl)
- {
- ((ConfigurerImpl)delegate).setApplicationContext(ctx);
- }
- }
-}
Modified: stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/configuration/SpringBusHolder.java
===================================================================
--- stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/configuration/SpringBusHolder.java 2011-04-24 22:04:33 UTC (rev 14190)
+++ stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/configuration/SpringBusHolder.java 2011-04-25 00:10:23 UTC (rev 14191)
@@ -42,6 +42,7 @@
import org.jboss.wsf.spi.binding.BindingCustomization;
import org.jboss.wsf.spi.deployment.Endpoint;
import org.jboss.wsf.stack.cxf.client.configuration.JBossWSSpringBusFactory;
+import org.jboss.wsf.stack.cxf.client.configuration.JBossWSSpringConfigurer;
import org.jboss.wsf.stack.cxf.deployment.WSDLFilePublisher;
import org.jboss.wsf.stack.cxf.spring.handler.NamespaceHandlerResolver;
import org.springframework.beans.factory.xml.XmlBeanDefinitionReader;
@@ -159,7 +160,9 @@
customizer.setBindingCustomization(customization);
customizer.setWsdlPublisher(wsdlPublisher);
customizer.setDeploymentEndpoints(depEndpoints);
- JBossWSServerSpringConfigurer serverConfigurer = new JBossWSServerSpringConfigurer(bus.getExtension(Configurer.class), ctx);
+ Configurer orig = bus.getExtension(Configurer.class);
+ JBossWSSpringConfigurer serverConfigurer = (orig instanceof JBossWSSpringConfigurer) ? (JBossWSSpringConfigurer)orig : new JBossWSSpringConfigurer(orig);
+ serverConfigurer.setApplicationContext(ctx);
serverConfigurer.setCustomizer(customizer);
return serverConfigurer;
}
Modified: stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/spring/parser/JaxwsEndpointDefinitionParser.java
===================================================================
--- stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/spring/parser/JaxwsEndpointDefinitionParser.java 2011-04-24 22:04:33 UTC (rev 14190)
+++ stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/spring/parser/JaxwsEndpointDefinitionParser.java 2011-04-25 00:10:23 UTC (rev 14191)
@@ -22,9 +22,10 @@
package org.jboss.wsf.stack.cxf.spring.parser;
import org.apache.cxf.Bus;
-import org.apache.cxf.BusFactory;
import org.apache.cxf.bus.spring.BusWiringBeanFactoryPostProcessor;
+import org.apache.cxf.configuration.Configurer;
import org.apache.cxf.jaxws.spring.EndpointDefinitionParser;
+import org.jboss.wsf.stack.cxf.client.configuration.JBossWSSpringConfigurer;
import org.jboss.wsf.stack.cxf.deployment.EndpointImpl;
import org.springframework.beans.BeansException;
import org.springframework.context.ApplicationContext;
@@ -63,9 +64,13 @@
{
if (getBus() == null)
{
- Bus bus = BusFactory.getThreadDefaultBus();
- BusWiringBeanFactoryPostProcessor.updateBusReferencesInContext(bus, ctx);
+ Bus bus = BusWiringBeanFactoryPostProcessor.addDefaultBus(ctx);
setBus(bus);
+ Configurer configurer = bus.getExtension(Configurer.class);
+ if (configurer instanceof JBossWSSpringConfigurer)
+ {
+ ((JBossWSSpringConfigurer) configurer).addApplicationContext(ctx);
+ }
}
}
}
13 years, 10 months
JBossWS SVN: r14190 - in stack/cxf/branches/cxf24: modules/client and 2 other directories.
by jbossws-commits@lists.jboss.org
Author: alessio.soldano(a)jboss.com
Date: 2011-04-24 18:04:33 -0400 (Sun, 24 Apr 2011)
New Revision: 14190
Modified:
stack/cxf/branches/cxf24/
stack/cxf/branches/cxf24/modules/client/pom.xml
stack/cxf/branches/cxf24/modules/resources/src/main/resources/modules/org/jboss/ws/tools/common/main/module.xml
stack/cxf/branches/cxf24/modules/testsuite/pom.xml
stack/cxf/branches/cxf24/pom.xml
Log:
svn merge -r 14167:HEAD https://svn.jboss.org/repos/jbossws/stack/cxf/trunk
Property changes on: stack/cxf/branches/cxf24
___________________________________________________________________
Modified: svn:mergeinfo
- /stack/cxf/branches/asoldano:14032-14050,14068
+ /stack/cxf/branches/asoldano:14032-14050,14068
/stack/cxf/trunk:14168-14189
Modified: stack/cxf/branches/cxf24/modules/client/pom.xml
===================================================================
--- stack/cxf/branches/cxf24/modules/client/pom.xml 2011-04-24 21:57:36 UTC (rev 14189)
+++ stack/cxf/branches/cxf24/modules/client/pom.xml 2011-04-24 22:04:33 UTC (rev 14190)
@@ -282,7 +282,7 @@
<customClasspathLayout>$${artifact.artifactId}.$${artifact.extension}</customClasspathLayout>
</manifest>
<manifestEntries>
- <Class-Path>jaxws-api.jar jboss-logging.jar jboss-logging-spi.jar jboss-logging-log4j.jar jcl-over-slf4j.jar slf4j-api.jar slf4j-jboss-logging.jar stax-api.jar wstx.jar wstx-lgpl.jar</Class-Path>
+ <Class-Path>jbossws-common-tools.jar jaxws-api.jar jboss-logging.jar jboss-logging-spi.jar jboss-logging-log4j.jar jcl-over-slf4j.jar slf4j-api.jar slf4j-jboss-logging.jar stax-api.jar wstx.jar wstx-lgpl.jar</Class-Path>
</manifestEntries>
</archive>
</configuration>
Modified: stack/cxf/branches/cxf24/modules/resources/src/main/resources/modules/org/jboss/ws/tools/common/main/module.xml
===================================================================
--- stack/cxf/branches/cxf24/modules/resources/src/main/resources/modules/org/jboss/ws/tools/common/main/module.xml 2011-04-24 21:57:36 UTC (rev 14189)
+++ stack/cxf/branches/cxf24/modules/resources/src/main/resources/modules/org/jboss/ws/tools/common/main/module.xml 2011-04-24 22:04:33 UTC (rev 14190)
@@ -31,8 +31,12 @@
<dependencies>
<module name="gnu.getopt"/>
<module name="org.apache.log4j"/>
- <module name="org.jboss.modules"/>
- <module name="org.jboss.ws.api"/>
+ <module name="org.jboss.as.webservices.server.integration" services="import">
+ <imports>
+ <include path="META-INF"/>
+ <include path="META-INF/cxf"/>
+ </imports>
+ </module>
</dependencies>
</module>
Modified: stack/cxf/branches/cxf24/modules/testsuite/pom.xml
===================================================================
--- stack/cxf/branches/cxf24/modules/testsuite/pom.xml 2011-04-24 21:57:36 UTC (rev 14189)
+++ stack/cxf/branches/cxf24/modules/testsuite/pom.xml 2011-04-24 22:04:33 UTC (rev 14190)
@@ -828,7 +828,7 @@
<profile>
<id>jboss700</id>
<properties>
- <jboss.version>7.0.0.Beta3-SNAPSHOT</jboss.version>
+ <jboss.version>7.0.0.Beta4-SNAPSHOT</jboss.version>
<jbossws.integration.target>jboss700</jbossws.integration.target>
</properties>
<dependencies>
Modified: stack/cxf/branches/cxf24/pom.xml
===================================================================
--- stack/cxf/branches/cxf24/pom.xml 2011-04-24 21:57:36 UTC (rev 14189)
+++ stack/cxf/branches/cxf24/pom.xml 2011-04-24 22:04:33 UTC (rev 14190)
@@ -56,7 +56,7 @@
<jbossws.jboss601.version>3.2.1.GA</jbossws.jboss601.version>
-->
<!-- END -->
- <jboss700.version>7.0.0.Beta3-SNAPSHOT</jboss700.version>
+ <jboss700.version>7.0.0.Beta4-SNAPSHOT</jboss700.version>
<cxf.version>2.4.0</cxf.version>
<cxf.asm.version>3.3</cxf.asm.version>
<cxf.xjcplugins.version>2.3.2</cxf.xjcplugins.version>
13 years, 10 months
JBossWS SVN: r14189 - stack/native/trunk/modules/testsuite.
by jbossws-commits@lists.jboss.org
Author: alessio.soldano(a)jboss.com
Date: 2011-04-24 17:57:36 -0400 (Sun, 24 Apr 2011)
New Revision: 14189
Modified:
stack/native/trunk/modules/testsuite/pom.xml
Log:
Move AS7 dep to 7.0.0.Beta4-SNAPSHOT
Modified: stack/native/trunk/modules/testsuite/pom.xml
===================================================================
--- stack/native/trunk/modules/testsuite/pom.xml 2011-04-24 21:24:30 UTC (rev 14188)
+++ stack/native/trunk/modules/testsuite/pom.xml 2011-04-24 21:57:36 UTC (rev 14189)
@@ -671,7 +671,7 @@
<profile>
<id>jboss700</id>
<properties>
- <jboss.version>7.0.0.Beta3-SNAPSHOT</jboss.version>
+ <jboss.version>7.0.0.Beta4-SNAPSHOT</jboss.version>
<jbossws.integration.target>jboss700</jbossws.integration.target>
<endorsed.dirs>${project.build.directory}/endorsed</endorsed.dirs>
</properties>
13 years, 10 months
JBossWS SVN: r14188 - in stack/cxf/trunk: modules/testsuite and 1 other directory.
by jbossws-commits@lists.jboss.org
Author: alessio.soldano(a)jboss.com
Date: 2011-04-24 17:24:30 -0400 (Sun, 24 Apr 2011)
New Revision: 14188
Modified:
stack/cxf/trunk/modules/testsuite/pom.xml
stack/cxf/trunk/pom.xml
Log:
Move AS 7 dep to 7.0.0.Beta4-SNAPSHOT
Modified: stack/cxf/trunk/modules/testsuite/pom.xml
===================================================================
--- stack/cxf/trunk/modules/testsuite/pom.xml 2011-04-22 16:21:34 UTC (rev 14187)
+++ stack/cxf/trunk/modules/testsuite/pom.xml 2011-04-24 21:24:30 UTC (rev 14188)
@@ -828,7 +828,7 @@
<profile>
<id>jboss700</id>
<properties>
- <jboss.version>7.0.0.Beta3-SNAPSHOT</jboss.version>
+ <jboss.version>7.0.0.Beta4-SNAPSHOT</jboss.version>
<jbossws.integration.target>jboss700</jbossws.integration.target>
</properties>
<dependencies>
Modified: stack/cxf/trunk/pom.xml
===================================================================
--- stack/cxf/trunk/pom.xml 2011-04-22 16:21:34 UTC (rev 14187)
+++ stack/cxf/trunk/pom.xml 2011-04-24 21:24:30 UTC (rev 14188)
@@ -56,7 +56,7 @@
<jbossws.jboss601.version>3.2.1.GA</jbossws.jboss601.version>
-->
<!-- END -->
- <jboss700.version>7.0.0.Beta3-SNAPSHOT</jboss700.version>
+ <jboss700.version>7.0.0.Beta4-SNAPSHOT</jboss700.version>
<cxf.version>2.3.4</cxf.version>
<cxf.asm.version>3.3</cxf.asm.version>
<cxf.xjcplugins.version>2.3.2</cxf.xjcplugins.version>
13 years, 10 months
JBossWS SVN: r14187 - in stack/cxf/branches/cxf24/modules: server/src/main/java/org/jboss/wsf/stack/cxf/configuration and 1 other directory.
by jbossws-commits@lists.jboss.org
Author: alessio.soldano(a)jboss.com
Date: 2011-04-22 12:21:34 -0400 (Fri, 22 Apr 2011)
New Revision: 14187
Removed:
stack/cxf/branches/cxf24/modules/client/src/main/java/org/jboss/wsf/stack/cxf/client/configuration/JBossWSBusApplicationContext.java
Modified:
stack/cxf/branches/cxf24/modules/client/src/main/java/org/jboss/wsf/stack/cxf/client/configuration/JBossWSSpringBusFactory.java
stack/cxf/branches/cxf24/modules/client/src/main/java/org/jboss/wsf/stack/cxf/client/configuration/JBossWSSpringConfigurer.java
stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/configuration/JBossWSServerSpringConfigurer.java
stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/configuration/SpringBusHolder.java
Log:
Fix spring bus creation
Deleted: stack/cxf/branches/cxf24/modules/client/src/main/java/org/jboss/wsf/stack/cxf/client/configuration/JBossWSBusApplicationContext.java
===================================================================
--- stack/cxf/branches/cxf24/modules/client/src/main/java/org/jboss/wsf/stack/cxf/client/configuration/JBossWSBusApplicationContext.java 2011-04-22 14:47:08 UTC (rev 14186)
+++ stack/cxf/branches/cxf24/modules/client/src/main/java/org/jboss/wsf/stack/cxf/client/configuration/JBossWSBusApplicationContext.java 2011-04-22 16:21:34 UTC (rev 14187)
@@ -1,121 +0,0 @@
-/*
- * JBoss, Home of Professional Open Source.
- * Copyright 2010, Red Hat Middleware LLC, and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
- */
-package org.jboss.wsf.stack.cxf.client.configuration;
-
-import java.io.BufferedReader;
-import java.io.IOException;
-import java.io.InputStream;
-import java.io.InputStreamReader;
-import java.net.URL;
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.List;
-
-import org.apache.cxf.bus.spring.BusApplicationContext;
-import org.springframework.context.ApplicationContext;
-import org.springframework.core.io.Resource;
-import org.springframework.core.io.support.PathMatchingResourcePatternResolver;
-
-/**
- * A JBossWS version of @see{org.apache.cxf.bus.spring.BusApplicationContext} that
- * allows for getting the default bus configuration from the JBossWS
- * integration.
- *
- * @author alessio.soldano(a)jboss.com
- * @since 25-May-2010
- *
- */
-public class JBossWSBusApplicationContext extends BusApplicationContext
-{
- private static final String JBWS_INTEGRATION_CXF_CFG_FILE = "META-INF/cxf/jbossws-cxf.xml";
-
- private static final String JBWS_CXF_EXT_CFG_FILE = "classpath*:META-INF/cxf/cxf-extension-jbossws.xml";
-
- private static final String DEFAULT_CXF_EXT_CFG_FILE = "classpath*:META-INF/cxf/cxf.extension";
-
- private final boolean jbwsIncludeDefaults;
- private final boolean ready;
-
- public JBossWSBusApplicationContext(String[] cf, boolean include, ApplicationContext parent)
- {
- super(cf, false, parent);
- this.jbwsIncludeDefaults = include;
- this.ready = true;
- refresh();
- }
-
- public JBossWSBusApplicationContext(URL[] url, boolean include, ApplicationContext parent)
- {
- super(url, false, parent);
- this.jbwsIncludeDefaults = include;
- this.ready = true;
- refresh();
- }
-
- @Override
- protected Resource[] getConfigResources()
- {
- List<Resource> resources = new ArrayList<Resource>();
- if (ready)
- {
- if (jbwsIncludeDefaults)
- {
- try
- {
- PathMatchingResourcePatternResolver resolver = new PathMatchingResourcePatternResolver(Thread
- .currentThread().getContextClassLoader());
- //jbossws-cxf.xml with our integration defaults for the Bus
- Collections.addAll(resources, resolver.getResources(JBWS_INTEGRATION_CXF_CFG_FILE));
- //cxf-extensions-jbossws.xml, for customers' jbossws additions
- Collections.addAll(resources, resolver.getResources(JBWS_CXF_EXT_CFG_FILE));
- //CXF vanilla extensions, need to load them here as super skips defaults loading
- Resource[] exts = resolver.getResources(DEFAULT_CXF_EXT_CFG_FILE);
- for (Resource r : exts)
- {
- InputStream is = r.getInputStream();
- BufferedReader rd = new BufferedReader(new InputStreamReader(is, "UTF-8"));
- String line = rd.readLine();
- while (line != null)
- {
- if (!"".equals(line))
- {
- resources.add(resolver.getResource(line));
- }
- line = rd.readLine();
- }
- is.close();
- }
-
- }
- catch (IOException ex)
- {
- // ignore
- }
- }
- //recurse to super; this loads everything else the user specified
- Resource[] superResources = super.getConfigResources();
- if (superResources != null)
- Collections.addAll(resources, superResources);
- }
- return resources.isEmpty() ? null : (Resource[]) resources.toArray(new Resource[resources.size()]);
- }
-}
Modified: stack/cxf/branches/cxf24/modules/client/src/main/java/org/jboss/wsf/stack/cxf/client/configuration/JBossWSSpringBusFactory.java
===================================================================
--- stack/cxf/branches/cxf24/modules/client/src/main/java/org/jboss/wsf/stack/cxf/client/configuration/JBossWSSpringBusFactory.java 2011-04-22 14:47:08 UTC (rev 14186)
+++ stack/cxf/branches/cxf24/modules/client/src/main/java/org/jboss/wsf/stack/cxf/client/configuration/JBossWSSpringBusFactory.java 2011-04-22 16:21:34 UTC (rev 14187)
@@ -22,16 +22,17 @@
package org.jboss.wsf.stack.cxf.client.configuration;
import java.net.URL;
-//import java.util.logging.Level;
-//import java.util.logging.Logger;
+import java.util.logging.Level;
+import java.util.logging.Logger;
import org.apache.cxf.Bus;
import org.apache.cxf.bus.spring.BusApplicationContext;
import org.apache.cxf.bus.spring.SpringBusFactory;
import org.apache.cxf.buslifecycle.BusLifeCycleListener;
import org.apache.cxf.buslifecycle.BusLifeCycleManager;
-//import org.apache.cxf.common.logging.LogUtils;
-//import org.springframework.beans.BeansException;
+import org.apache.cxf.common.logging.LogUtils;
+import org.apache.cxf.configuration.Configurer;
+import org.springframework.beans.BeansException;
import org.springframework.context.ApplicationContext;
/**
@@ -44,7 +45,7 @@
*/
public class JBossWSSpringBusFactory extends SpringBusFactory
{
-// private static final Logger LOG = LogUtils.getL7dLogger(JBossWSSpringBusFactory.class);
+ private static final Logger LOG = LogUtils.getL7dLogger(JBossWSSpringBusFactory.class);
public JBossWSSpringBusFactory()
{
@@ -56,91 +57,92 @@
super(context);
}
+ /**
+ * We override the Apache CXF method to skip the checks on cxf.xml conf file as that would prevent
+ * creating a Spring version of the bus when the jbossws-cxf.xml is available; generally speaking
+ * the JBossWS-CXF integration requires a Spring bus to be created by Spring bus factories.
+ */
@Override
public Bus createBus(String cfgFiles[], boolean includeDefaults)
{
-// try
-// {
-// return finishCreatingBus(createApplicationContext(cfgFiles, includeDefaults));
-// }
-// catch (BeansException ex)
-// {
-// LogUtils.log(LOG, Level.WARNING, "APP_CONTEXT_CREATION_FAILED_MSG", ex, (Object[]) null);
-// throw new RuntimeException(ex);
-// }
- Bus bus = super.createBus(cfgFiles, includeDefaults);
- finalizeBusCreation(bus);
- return bus;
+ try
+ {
+ return finishCreatingBus(createApplicationContext(cfgFiles, includeDefaults));
+ }
+ catch (BeansException ex)
+ {
+ LogUtils.log(LOG, Level.WARNING, "APP_CONTEXT_CREATION_FAILED_MSG", ex, (Object[]) null);
+ throw new RuntimeException(ex);
+ }
}
@Override
public Bus createBus(URL[] urls, boolean includeDefaults)
{
-// try
-// {
-// return finishCreatingBus(new JBossWSBusApplicationContext(urls, includeDefaults, getApplicationContext()));
-// }
-// catch (BeansException ex)
-// {
-// LogUtils.log(LOG, Level.WARNING, "APP_CONTEXT_CREATION_FAILED_MSG", ex, (Object[]) null);
-// throw new RuntimeException(ex);
-// }
- Bus bus = super.createBus(urls, includeDefaults);
- finalizeBusCreation(bus);
+ try
+ {
+ return finishCreatingBus(new BusApplicationContext(urls, includeDefaults, getApplicationContext()));
+ }
+ catch (BeansException ex)
+ {
+ LogUtils.log(LOG, Level.WARNING, "APP_CONTEXT_CREATION_FAILED_MSG", ex, (Object[]) null);
+ throw new RuntimeException(ex);
+ }
+ }
+
+ private Bus finishCreatingBus(BusApplicationContext bac)
+ {
+ final Bus bus = (Bus) bac.getBean(Bus.DEFAULT_BUS_ID);
+
+ bus.setExtension(bac, BusApplicationContext.class);
+
+ setConfigurer(bus);
+
+ possiblySetDefaultBus(bus);
+
+ initializeBus(bus);
+
+ registerAppContextLifeCycleListener(bus, bac);
return bus;
}
+
+ private BusApplicationContext createApplicationContext(String cfgFiles[], boolean includeDefaults)
+ {
+ try
+ {
+ return new BusApplicationContext(cfgFiles, includeDefaults, getApplicationContext());
+ }
+ catch (BeansException ex)
+ {
+ LogUtils.log(LOG, Level.WARNING, "INITIAL_APP_CONTEXT_CREATION_FAILED_MSG", ex, (Object[]) null);
+ ClassLoader contextLoader = Thread.currentThread().getContextClassLoader();
+ if (contextLoader != BusApplicationContext.class.getClassLoader())
+ {
+ Thread.currentThread().setContextClassLoader(BusApplicationContext.class.getClassLoader());
+ try
+ {
+ return new BusApplicationContext(cfgFiles, includeDefaults, getApplicationContext());
+ }
+ finally
+ {
+ Thread.currentThread().setContextClassLoader(contextLoader);
+ }
+ }
+ else
+ {
+ throw ex;
+ }
+ }
+ }
- private static void finalizeBusCreation(Bus bus)
+ private void setConfigurer(Bus bus)
{
- //TODO!! also set our custom configurer
- BusApplicationContext bac = bus.getExtension(BusApplicationContext.class);
- registerAppContextLifeCycleListener(bus, bac);
+ JBossWSSpringConfigurer configurer = new JBossWSSpringConfigurer(bus.getExtension(Configurer.class));
+ configurer.setCustomizer(new BeanCustomizer());
+ bus.setExtension(configurer, Configurer.class);
}
-// private Bus finishCreatingBus(BusApplicationContext bac)
-// {
-// final Bus bus = (Bus) bac.getBean(Bus.DEFAULT_BUS_ID);
-//
-// bus.setExtension(bac, BusApplicationContext.class);
-//
-// possiblySetDefaultBus(bus);
-//
-// initializeBus(bus);
-//
-// registerAppContextLifeCycleListener(bus, bac);
-// return bus;
-// }
-//
-// private BusApplicationContext createApplicationContext(String cfgFiles[], boolean includeDefaults)
-// {
-// try
-// {
-// return new JBossWSBusApplicationContext(cfgFiles, includeDefaults, getApplicationContext());
-// }
-// catch (BeansException ex)
-// {
-// LogUtils.log(LOG, Level.WARNING, "INITIAL_APP_CONTEXT_CREATION_FAILED_MSG", ex, (Object[]) null);
-// ClassLoader contextLoader = Thread.currentThread().getContextClassLoader();
-// if (contextLoader != BusApplicationContext.class.getClassLoader())
-// {
-// Thread.currentThread().setContextClassLoader(BusApplicationContext.class.getClassLoader());
-// try
-// {
-// return new JBossWSBusApplicationContext(cfgFiles, includeDefaults, getApplicationContext());
-// }
-// finally
-// {
-// Thread.currentThread().setContextClassLoader(contextLoader);
-// }
-// }
-// else
-// {
-// throw ex;
-// }
-// }
-// }
-
- static void registerAppContextLifeCycleListener(final Bus bus, final BusApplicationContext bac)
+ void registerAppContextLifeCycleListener(final Bus bus, final BusApplicationContext bac)
{
BusLifeCycleManager lm = bus.getExtension(BusLifeCycleManager.class);
if (null != lm)
Modified: stack/cxf/branches/cxf24/modules/client/src/main/java/org/jboss/wsf/stack/cxf/client/configuration/JBossWSSpringConfigurer.java
===================================================================
--- stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/configuration/JBossWSServerSpringConfigurer.java 2011-04-22 14:47:08 UTC (rev 14186)
+++ stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/configuration/JBossWSServerSpringConfigurer.java 2011-04-22 16:21:34 UTC (rev 14187)
@@ -21,6 +21,8 @@
*/
package org.jboss.wsf.stack.cxf.configuration;
+import org.apache.cxf.configuration.Configurer;
+import org.apache.cxf.configuration.spring.ConfigurerImpl;
import org.jboss.wsf.stack.cxf.client.configuration.JBossWSSpringConfigurer;
import org.springframework.context.ApplicationContext;
@@ -33,8 +35,12 @@
*/
public class JBossWSServerSpringConfigurer extends JBossWSSpringConfigurer
{
- public JBossWSServerSpringConfigurer(ApplicationContext ctx)
+ public JBossWSServerSpringConfigurer(Configurer delegate, ApplicationContext ctx)
{
- setApplicationContext(ctx);
+ super(delegate);
+ if (delegate instanceof ConfigurerImpl)
+ {
+ ((ConfigurerImpl)delegate).setApplicationContext(ctx);
+ }
}
}
Modified: stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/configuration/SpringBusHolder.java
===================================================================
--- stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/configuration/SpringBusHolder.java 2011-04-22 14:47:08 UTC (rev 14186)
+++ stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/configuration/SpringBusHolder.java 2011-04-22 16:21:34 UTC (rev 14187)
@@ -159,7 +159,7 @@
customizer.setBindingCustomization(customization);
customizer.setWsdlPublisher(wsdlPublisher);
customizer.setDeploymentEndpoints(depEndpoints);
- JBossWSServerSpringConfigurer serverConfigurer = new JBossWSServerSpringConfigurer(ctx);
+ JBossWSServerSpringConfigurer serverConfigurer = new JBossWSServerSpringConfigurer(bus.getExtension(Configurer.class), ctx);
serverConfigurer.setCustomizer(customizer);
return serverConfigurer;
}
13 years, 10 months
JBossWS SVN: r14186 - stack/cxf/branches/cxf24/modules/addons/transports/http/httpserver/src/main/java/org/jboss/wsf/stack/cxf/addons/transports/httpserver.
by jbossws-commits@lists.jboss.org
Author: alessio.soldano(a)jboss.com
Date: 2011-04-22 10:47:08 -0400 (Fri, 22 Apr 2011)
New Revision: 14186
Modified:
stack/cxf/branches/cxf24/modules/addons/transports/http/httpserver/src/main/java/org/jboss/wsf/stack/cxf/addons/transports/httpserver/HttpServerEngine.java
Log:
Removing System.out.println()
Modified: stack/cxf/branches/cxf24/modules/addons/transports/http/httpserver/src/main/java/org/jboss/wsf/stack/cxf/addons/transports/httpserver/HttpServerEngine.java
===================================================================
--- stack/cxf/branches/cxf24/modules/addons/transports/http/httpserver/src/main/java/org/jboss/wsf/stack/cxf/addons/transports/httpserver/HttpServerEngine.java 2011-04-22 13:01:25 UTC (rev 14185)
+++ stack/cxf/branches/cxf24/modules/addons/transports/http/httpserver/src/main/java/org/jboss/wsf/stack/cxf/addons/transports/httpserver/HttpServerEngine.java 2011-04-22 14:47:08 UTC (rev 14186)
@@ -131,7 +131,6 @@
}
else
{
- System.out.println("******* " + factory + " ****** handlerCount="+handlerCount);
LOG.log(Level.WARNING, "FAILED_TO_SHUTDOWN_ENGINE_MSG", port);
}
}
13 years, 10 months
--- stack/cxf/branches/cxf24/modules/client/src/main/java/org/jboss/wsf/stack/cxf/client/configuration/JBossWSSpringConfigurer.java 2011-04-22 14:47:08 UTC (rev 14186)
+++ stack/cxf/branches/cxf24/modules/client/src/main/java/org/jboss/wsf/stack/cxf/client/configuration/JBossWSSpringConfigurer.java 2011-04-22 16:21:34 UTC (rev 14187)
@@ -21,30 +21,37 @@
*/
package org.jboss.wsf.stack.cxf.client.configuration;
-import org.apache.cxf.configuration.spring.ConfigurerImpl;
+import org.apache.cxf.configuration.Configurer;
/**
* A CXF configurer (Spring based) that sets JBossWS stuff / customizations / properties etc. in CXF configurable beans
*
* @author alessio.soldano(a)jboss.com
* @since 05-Oct-2009
*/
-public class JBossWSSpringConfigurer extends ConfigurerImpl implements JBossWSConfigurer
+public class JBossWSSpringConfigurer implements JBossWSConfigurer
{
private BeanCustomizer customizer;
+ private Configurer delegate;
+
+ public JBossWSSpringConfigurer(Configurer delegate)
+ {
+ this.delegate = delegate;
+ }
@Override
public void configureBean(Object beanInstance)
{
customConfigure(beanInstance);
- super.configureBean(beanInstance);
+ delegate.configureBean(beanInstance);
}
@Override
public void configureBean(String name, Object beanInstance)
{
customConfigure(beanInstance);
- super.configureBean(name, beanInstance);
+ delegate.configureBean(name, beanInstance);
}
protected synchronized void customConfigure(Object beanInstance)
Modified: stack/cxf/branches/cxf24/modules/server/src/main/java/org/jboss/wsf/stack/cxf/configuration/JBossWSServerSpringConfigurer.java
@@ -21,30 +21,37 @@
/**
- * A CXF configurer (Spring based) that sets JBossWS stuff / customizations / properties etc. in CXF configurable beans
+ * A CXF delegate configurer that sets JBossWS stuff / customizations / properties etc. in CXF configurable beans
+ * (to be used for Spring based bus)
*
* @author alessio.soldano(a)jboss.com
===================================================================